aboutsummaryrefslogtreecommitdiff
path: root/mod/walledgarden/index.php
diff options
context:
space:
mode:
Diffstat (limited to 'mod/walledgarden/index.php')
-rw-r--r--mod/walledgarden/index.php43
1 files changed, 22 insertions, 21 deletions
diff --git a/mod/walledgarden/index.php b/mod/walledgarden/index.php
index ca822d78a..251725496 100644
--- a/mod/walledgarden/index.php
+++ b/mod/walledgarden/index.php
@@ -1,24 +1,25 @@
<?php
+/**
+ * Elgg Walled Garden
+ *
+ * @package WalledGarden
+ * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
+ * @author Curverider Ltd <info@elgg.com>
+ * @copyright Curverider Ltd 2008
+ * @link http://elgg.com/
+ */
- /**
- * Elgg custom index
- *
- * @package ElggCustomIndex
- * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU Public License version 2
- * @author Curverider Ltd <info@elgg.com>
- * @copyright Curverider Ltd 2008
- * @link http://elgg.com/
- */
-
- // Get the Elgg engine
- require_once(dirname(dirname(dirname(__FILE__))) . "/engine/start.php");
-
- //grab the login form
- $login = elgg_view("account/forms/login");
+// Get the Elgg engine
+require_once(dirname(dirname(dirname(__FILE__))) . "/engine/start.php");
- //display the contents in our new canvas layout
- $body = elgg_view_layout('new_index',$login);
-
- page_draw($title, $body);
-
-?> \ No newline at end of file
+//grab the login form
+$login = elgg_view("account/forms/login");
+
+//temp message
+$area1 = "This site is running in walled garden mode. <br />
+ Therefore you will need to be invited & logged in to see anything.";
+
+//display the contents in our new canvas layout
+$body = elgg_view_layout('one_column_with_sidebar', $login, $area1);
+
+page_draw($title, $body); \ No newline at end of file